pub trait WeakKeepalive: Send + Sync { // Required method fn upgrade(&self) -> Option<Arc<dyn Keepalive>>; }
Counterpart to Keepalive: a non-pinning reference to the same underlying resource that can be re-promoted to a Keepalive as long as the resource is still alive.
Keepalive
Re-acquire a strong Keepalive for the underlying resource, or None if the referent has gone away.
None